import {
  physicaldeviceonboarding_default
} from "./chunk-GSHMK4U3.js";
import {
  virtualdeviceonboarding_default
} from "./chunk-3X7YKD7O.js";
import {
  HELPTOOLTIPS,
  MenderHelpTooltip
} from "./chunk-BRBHG7I6.js";
import {
  infotext_default
} from "./chunk-AMEA5SGJ.js";
import {
  docslink_default
} from "./chunk-EUHS2BAH.js";
import {
  loader_default
} from "./chunk-IRS4QQ7I.js";

// src/dialogs/deviceconnectiondialog.js
import React, { useEffect, useState } from "react";
import { useDispatch, useSelector } from "react-redux";
import { useNavigate } from "react-router-dom";
import { Button, Dialog, DialogActions, DialogContent, DialogTitle } from "@mui/material";
import { makeStyles } from "tss-react/mui";
import { DEVICE_STATES, TIMEOUTS, onboardingSteps } from "@northern.tech/store/constants";
import { getDeviceCountsByStatus, getOnboardingState, getTenantCapabilities } from "@northern.tech/store/selectors";
import { advanceOnboarding, saveUserSettings, setDeviceListState } from "@northern.tech/store/thunks";

// ../../assets/img/docker.png
var docker_default = "./docker-NSLOZBPD.png";

// ../../assets/img/raspberrypi4.png
var raspberrypi4_default = "./raspberrypi4-RE2Z6223.png";

// ../../assets/img/raspberrypi.png
var raspberrypi_default = "./raspberrypi-Q67HH5QM.png";

// src/dialogs/deviceconnectiondialog.js
import { Fragment, jsx, jsxs } from "react/jsx-runtime";
var useStyles = makeStyles()((theme) => ({
  rpiQuickstart: {
    backgroundColor: theme.palette.background.lightgrey
  },
  virtualLogo: { height: 40, marginLeft: theme.spacing(2) }
}));
var DeviceConnectionExplainer = ({ hasMonitor, setOnDevice, setVirtualDevice }) => {
  const { classes } = useStyles();
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    /* @__PURE__ */ jsx("p", { children: "You can connect almost any device and Linux OS with Mender, but to make things simple during evaluation we recommend you use a Raspberry Pi as a test device." }),
    /* @__PURE__ */ jsxs("div", { className: `padding-small padding-top-none rpi-quickstart ${classes.rpiQuickstart}`, children: [
      /* @__PURE__ */ jsx("h3", { children: "Raspberry Pi quick start" }),
      /* @__PURE__ */ jsx("p", { children: "We'll walk you through the steps to connect a Raspberry Pi and deploy your first update with Mender." }),
      /* @__PURE__ */ jsxs("div", { className: "flexbox column centered", children: [
        /* @__PURE__ */ jsx("div", { className: "flexbox centered os-list", children: [raspberrypi_default, raspberrypi4_default].map((tile, index) => /* @__PURE__ */ jsx("img", { src: tile }, `tile-${index}`)) }),
        /* @__PURE__ */ jsx(Button, { variant: "contained", color: "secondary", onClick: () => setOnDevice(true), children: "Get Started" })
      ] })
    ] }),
    /* @__PURE__ */ jsxs("div", { className: "two-columns margin-top", children: [
      /* @__PURE__ */ jsxs("div", { className: "padding-small padding-top-none", children: [
        /* @__PURE__ */ jsxs("div", { className: "flexbox center-aligned", children: [
          /* @__PURE__ */ jsx("h3", { children: "Use a virtual device" }),
          /* @__PURE__ */ jsx("img", { src: docker_default, className: classes.virtualLogo })
        ] }),
        /* @__PURE__ */ jsx("p", { className: "margin-top-none", children: "Don't have a Raspberry Pi?" }),
        /* @__PURE__ */ jsx("p", { children: "You can use our Docker-run virtual device to go through the same tutorial." }),
        hasMonitor && /* @__PURE__ */ jsx(infotext_default, { className: "slightly-smaller", children: "If you want to evaluate our commercial components such as mender-monitor, please use a physical device instead as the virtual client does not support these components at this time." }),
        /* @__PURE__ */ jsx("a", { onClick: () => setVirtualDevice(true), children: "Try a virtual device" })
      ] }),
      /* @__PURE__ */ jsxs("div", { className: "padding-small padding-top-none", children: [
        /* @__PURE__ */ jsx("h3", { children: "Other devices" }),
        /* @__PURE__ */ jsx("div", { children: "See the documentation to integrate the following with Mender:" }),
        /* @__PURE__ */ jsx("ul", { children: [
          { key: "debian", target: "operating-system-updates-debian-family", title: "Debian family" },
          { key: "yocto", target: "operating-system-updates-yocto-project", title: "Yocto OSes" }
        ].map((item) => /* @__PURE__ */ jsx("li", { children: /* @__PURE__ */ jsx(docslink_default, { path: item.target, title: item.title }) }, item.key)) }),
        "Or visit ",
        /* @__PURE__ */ jsx("a", { href: "https://hub.mender.io/c/board-integrations", target: "_blank", rel: "noopener", children: "Mender Hub" }),
        " ",
        "and search integrations for your device and OS."
      ] })
    ] }),
    /* @__PURE__ */ jsx(MenderHelpTooltip, { id: HELPTOOLTIPS.deviceSupportTip.id, style: { position: "absolute", bottom: "2.5%", left: "88%" } })
  ] });
};
var DeviceConnectionDialog = ({ onCancel }) => {
  const [onDevice, setOnDevice] = useState(false);
  const [progress, setProgress] = useState(1);
  const [virtualDevice, setVirtualDevice] = useState(false);
  const { pending: pendingCount } = useSelector(getDeviceCountsByStatus);
  const [pendingDevicesCount] = useState(pendingCount);
  const [hasMoreDevices, setHasMoreDevices] = useState(false);
  const { hasMonitor } = useSelector(getTenantCapabilities);
  const { complete: onboardingComplete, deviceType: onboardingDeviceType } = useSelector(getOnboardingState);
  const dispatch = useDispatch();
  const navigate = useNavigate();
  useEffect(() => {
    setHasMoreDevices(pendingCount > pendingDevicesCount);
  }, [pendingDevicesCount, pendingCount]);
  useEffect(() => {
    if ((virtualDevice || progress >= 2) && hasMoreDevices && !window.location.hash.includes("pending")) {
      dispatch(advanceOnboarding(onboardingSteps.DASHBOARD_ONBOARDING_START));
      dispatch(setDeviceListState({ state: DEVICE_STATES.pending }));
      navigate("/devices/pending");
    }
    if (virtualDevice || progress >= 2) {
      dispatch(saveUserSettings({ onboarding: { deviceConnection: (/* @__PURE__ */ new Date()).toISOString() } }));
    }
  }, [dispatch, hasMoreDevices, navigate, progress, virtualDevice]);
  const onBackClick = () => {
    let updatedProgress = progress - 1;
    if (!updatedProgress) {
      updatedProgress = 1;
      setOnDevice(false);
      setVirtualDevice(false);
    }
    setProgress(updatedProgress);
  };
  const onAdvance = () => {
    dispatch(advanceOnboarding(onboardingSteps.DASHBOARD_ONBOARDING_START));
    setProgress(progress + 1);
  };
  let content = /* @__PURE__ */ jsx(DeviceConnectionExplainer, { hasMonitor, setOnDevice, setVirtualDevice });
  if (onDevice) {
    content = /* @__PURE__ */ jsx(physicaldeviceonboarding_default, { progress });
  } else if (virtualDevice) {
    content = /* @__PURE__ */ jsx(virtualdeviceonboarding_default, {});
  }
  if (hasMoreDevices && !onboardingComplete) {
    setTimeout(onCancel, TIMEOUTS.twoSeconds);
  }
  return /* @__PURE__ */ jsxs(Dialog, { open: true, PaperProps: { sx: { maxWidth: "720px" } }, children: [
    /* @__PURE__ */ jsx(DialogTitle, { children: "Connecting a device" }),
    /* @__PURE__ */ jsx(DialogContent, { className: "onboard-dialog", style: { margin: "0 30px" }, children: content }),
    /* @__PURE__ */ jsxs(DialogActions, { children: [
      /* @__PURE__ */ jsx(Button, { onClick: onCancel, children: "Cancel" }),
      /* @__PURE__ */ jsx("div", { style: { flexGrow: 1 } }),
      (onDevice || virtualDevice) && /* @__PURE__ */ jsxs("div", { children: [
        /* @__PURE__ */ jsx(Button, { onClick: onBackClick, children: "Back" }),
        progress < 2 && (!virtualDevice || progress < 1) ? /* @__PURE__ */ jsx(Button, { variant: "contained", disabled: !(virtualDevice || onDevice && onboardingDeviceType), onClick: onAdvance, children: "Next" }) : /* @__PURE__ */ jsx(
          Button,
          {
            variant: "contained",
            disabled: !onboardingComplete,
            onClick: onCancel,
            endIcon: !onboardingComplete && /* @__PURE__ */ jsx(loader_default, { show: true, small: true, table: true, style: { top: -24 } }),
            children: onboardingComplete ? "Close" : "Waiting for device"
          }
        )
      ] })
    ] })
  ] });
};
var deviceconnectiondialog_default = DeviceConnectionDialog;

export {
  DeviceConnectionDialog,
  deviceconnectiondialog_default
};
//# sourceMappingURL=chunk-FGYAY366.js.map